@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Aufklappen</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Forumsteilnehmer auf Stufe 2 und höher können dem Betatest beitreten um die neuesten Aktualisierungen zu erhalten.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation type="unfinished"/>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
