@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>展開</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Level 2以上のフォーラムユーザーがベータテストに参加し最新のアップデートを受け取ることができます。</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>折りたたむ</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>1から99999の間で入力してください</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
