@@ -363,10 +363,6 @@
         <source>Expand</source>
         <translation>Genişlet</translation>
     </message>
-    <message>
-        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
-        <translation>Seviye 2 ve üzeri forum kullanıcıları son güncellemeleri almak için beta testine katılabilir.</translation>
-    </message>
     <message>
         <source>Collapse</source>
         <translation>Daralt</translation>
@@ -375,6 +371,10 @@
         <source>Only numbers between 1-99999 are allowed</source>
         <translation>Sadece 1-99999 arasındaki sayılara izin verilir</translation>
     </message>
+    <message>
+        <source>Join the internal testing channel to get deepin latest updates.</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>UpdateWorker</name>
